interface ApiResult<TData = any, TError = any> {
    loading: boolean;
    data: TData | null | undefined;
    error: TError | null | undefined;
}
export class Cache {
    data: Record<string, ApiResult>;
    subscriptions: Record<string, (() => void)[]>;
    get: <TData, TError>(key: string) => ApiResult<TData, TError>;
    set: <TData, TError>(key: string, value: ApiResult<TData, TError>) => void;
    subscribe: (key: string, callback: () => void) => void;
    unsubscribe: (key: string, callback: () => void) => void;
}
export type ApiVariables<T extends Partial<Record<'body' | 'query' | 'body', any>> = {}> = T;
interface ApiConfig<APIs> {
    fetcher: (api: APIs[keyof APIs], variables: ApiVariables) => Promise<unknown>;
}
type ApiProviderProps<T> = React.PropsWithChildren<{
    cache?: Cache;
    config: ApiConfig<T>;
}>;
export interface UseLazyApiOptions<TData, TError, TVariables> {
    cached?: boolean;
    variables?: TVariables;
    onFetch?: () => Promise<any>;
    onCompleted?: (params: {
        data: TData | null;
        error: TError | null;
    }) => Promise<any>;
}
export interface UseApiOptions<TData, TError, TVariables> extends UseLazyApiOptions<TData, TError, TVariables> {
    skip?: boolean;
    force?: boolean;
}
export function createAPIs<T, TData extends Record<keyof T, any> = any, TError extends Record<keyof T, any> = any, TVariables extends Record<keyof T, any> = any>(apis: T): {
    Provider: ({ config, children, cache, }: ApiProviderProps<T>) => JSX.Element;
    useLazyApi: <K extends keyof T, TApiData extends TData[K], TApiError extends TError[K], TApiVariables extends TVariables[K]>(key: K, defaultOpts?: UseLazyApiOptions<TApiData, TApiError, TApiVariables>) => readonly [(opts?: Pick<UseLazyApiOptions<TApiData, TApiError, TApiVariables>, "variables">) => Promise<{
        data: TApiData | null;
        error: TApiError | null;
    }>, {
        readonly refetch: (opts?: Pick<UseLazyApiOptions<TApiData, TApiError, TApiVariables>, "variables">) => Promise<{
            data: TApiData | null;
            error: TApiError | null;
        }>;
        readonly loading: boolean;
        readonly data: TApiData | null | undefined;
        readonly error: TApiError | null | undefined;
    }];
    useMutationApi: <K_1 extends keyof T, TApiData_1 extends TData[K_1], TApiError_1 extends TError[K_1], TApiVariables_1 extends TVariables[K_1]>(key: K_1, opts?: UseLazyApiOptions<TApiData_1, TApiError_1, TApiVariables_1>) => readonly [(opts?: Pick<UseLazyApiOptions<TApiData_1, TApiError_1, TApiVariables_1>, "variables">) => Promise<{
        data: TApiData_1 | null;
        error: TApiError_1 | null;
    }>, {
        readonly refetch: (opts?: Pick<UseLazyApiOptions<TApiData_1, TApiError_1, TApiVariables_1>, "variables">) => Promise<{
            data: TApiData_1 | null;
            error: TApiError_1 | null;
        }>;
        readonly loading: boolean;
        readonly data: TApiData_1 | null | undefined;
        readonly error: TApiError_1 | null | undefined;
    }];
    useApi: <K_2 extends keyof T, TApiData_2 extends TData[K_2], TApiError_2 extends TError[K_2], TApiVariables_2 extends TVariables[K_2]>(key: K_2, opts?: UseApiOptions<TApiData_2, TApiError_2, TApiVariables_2>) => {
        loading: boolean;
        called: boolean;
        refetch: (opts?: Pick<UseLazyApiOptions<TApiData_2, TApiError_2, TApiVariables_2>, "variables">) => Promise<{
            data: TApiData_2 | null;
            error: TApiError_2 | null;
        }>;
        data: TApiData_2 | null | undefined;
        error: TApiError_2 | null | undefined;
    };
};

//# sourceMappingURL=types.d.ts.map
